@@ -5,11 +5,13 @@
 #ifndef GJS_DEPRECATION_H_
 #define GJS_DEPRECATION_H_
 
+#include <config.h>
+
 #include <vector>
 
 struct JSContext;
 
-enum GjsDeprecationMessageId {
+enum GjsDeprecationMessageId : unsigned {
     None,
     ByteArrayInstanceToString,
     DeprecatedGObjectProperty,
