@@ -105,18 +105,18 @@ describe('Gio.Settings overrides', function () {
     });
 
     it("doesn't crash when specifying a schema ID that isn't installed", function () {
-        expect(() => new Gio.Settings({schema: 'com.example.ThisDoesntExist'}))
+        expect(() => new Gio.Settings({schemaId: 'com.example.ThisDoesntExist'}))
             .toThrowError(/schema/);
     });
 
     it("doesn't crash when forgetting to specify a schema path", function () {
-        expect(() => new Gio.Settings({schema: 'org.gnome.GjsTest.Sub'}))
+        expect(() => new Gio.Settings({schemaId: 'org.gnome.GjsTest.Sub'}))
             .toThrowError(/schema/);
     });
 
     it("doesn't crash when specifying conflicting schema paths", function () {
         expect(() => new Gio.Settings({
-            schema: 'org.gnome.GjsTest',
+            schemaId: 'org.gnome.GjsTest',
             path: '/conflicting/path/',
         })).toThrowError(/schema/);
     });
@@ -139,7 +139,7 @@ describe('Gio.Settings overrides', function () {
         let settings;
 
         beforeEach(function () {
-            settings = new Gio.Settings({schema: 'org.gnome.GjsTest'});
+            settings = new Gio.Settings({schemaId: 'org.gnome.GjsTest'});
         });
 
         it("doesn't crash when resetting a nonexistent key", function () {
