@@ -534,6 +534,25 @@ describe('Life, the Universe and Everything', function () {
         });
     });
 
+    it('enum that references its own members has correct values', function () {
+        expect(Regress.TestReferenceEnum.ZERO).toEqual(4);
+        expect(Regress.TestReferenceEnum.ONE).toEqual(2);
+        expect(Regress.TestReferenceEnum.TWO).toEqual(54);
+        expect(Regress.TestReferenceEnum.THREE).toEqual(4);
+        expect(Regress.TestReferenceEnum.FOUR).toEqual(216);
+        expect(Regress.TestReferenceEnum.FIVE).toEqual(-217);
+    });
+
+    it('unregistered enum works', function () {
+        expect(Regress.TestEnumNoGEnum.EVALUE1).toEqual(0);
+        expect(Regress.TestEnumNoGEnum.EVALUE2).toEqual(42);
+        expect(Regress.TestEnumNoGEnum.EVALUE3).toEqual('0'.charCodeAt());
+    });
+
+    it('value is not added to enum with #define', function () {
+        expect(Regress.TestEnumNoGEnum.EVALUE_DEPRECATED).not.toBeDefined();
+    });
+
     it('enum parameter', function () {
         expect(Regress.test_enum_param(Regress.TestEnum.VALUE1)).toEqual('value1');
         expect(Regress.test_enum_param(Regress.TestEnum.VALUE3)).toEqual('value3');
@@ -1234,8 +1253,6 @@ describe('Life, the Universe and Everything', function () {
             });
 
             it('signal with object with full transport gets correct arguments', function (done) {
-                if (!GObject.signal_lookup('sig-with-obj-full', Regress.TestObj.$gtype))
-                    pending('https://gitlab.gnome.org/GNOME/gobject-introspection/-/merge_requests/409');
                 o.connect('sig-with-obj-full', (self, objectParam) => {
                     expect(objectParam.int).toEqual(5);
                     done();
@@ -1244,9 +1261,6 @@ describe('Life, the Universe and Everything', function () {
             });
 
             it('signal with object with full transport gets correct arguments from JS', function (done) {
-                if (!GObject.signal_lookup('sig-with-obj-full', Regress.TestObj.$gtype))
-                    pending('https://gitlab.gnome.org/GNOME/gobject-introspection/-/merge_requests/409');
-
                 o.connect('sig-with-obj-full', (self, objectParam) => {
                     expect(objectParam.int).toEqual(55);
                     done();
@@ -1316,9 +1330,6 @@ describe('Life, the Universe and Everything', function () {
             });
 
             it('signal with GStrv parameter and transfer full is properly handled from JS', function (done) {
-                if (!GObject.signal_lookup('sig-with-strv-full', Regress.TestObj.$gtype))
-                    pending('https://gitlab.gnome.org/GNOME/gobject-introspection/-/merge_requests/409');
-
                 o.connect('sig-with-strv-full', (signalObj, signalArray, shouldBeUndefined) => {
                     expect(signalObj).toBe(o);
                     expect(shouldBeUndefined).not.toBeDefined();
@@ -1329,8 +1340,6 @@ describe('Life, the Universe and Everything', function () {
             });
 
             xit('signal with GStrv parameter and transfer full is properly handled', function (done) {
-                if (!o.emit_sig_with_gstrv_full)
-                    pending('https://gitlab.gnome.org/GNOME/gobject-introspection/-/merge_requests/409');
                 o.connect('sig-with-strv-full', (signalObj, signalArray, shouldBeUndefined) => {
                     expect(signalObj).toBe(o);
                     expect(shouldBeUndefined).not.toBeDefined();
