@@ -3,6 +3,8 @@
 // SPDX-FileCopyrightText: 2014 Endless Mobile, Inc.
 // SPDX-FileContributor: Authored By: Sam Spilsbury <sam@endlessm.com>
 
+#include <config.h>
+
 #include <errno.h>   // for errno
 #include <stdio.h>   // for sscanf, size_t
 #include <stdlib.h>  // for strtol, atoi, mkdtemp
@@ -36,7 +38,7 @@ static void
 replace_file(GFile      *file,
               const char *contents)
 {
-    GError *error = NULL;
+    GjsAutoError error;
     g_file_replace_contents(file, contents, strlen(contents), NULL /* etag */,
                             FALSE /* make backup */, G_FILE_CREATE_NONE,
                             NULL /* etag out */, NULL /* cancellable */, &error);
